***********************************
Monitoring
***********************************

Recording of neural or synaptic variables during the simulation is possible through a ``Monitor`` object.

Monitor class
================

.. autoclass:: ANNarchy.Monitor
   :members:

Offline methods
================

.. autofunction:: ANNarchy.raster_plot
.. autofunction:: ANNarchy.histogram
.. autofunction:: ANNarchy.mean_fr
.. autofunction:: ANNarchy.smoothed_rate
.. autofunction:: ANNarchy.population_rate